@@ -28,16 +28,18 @@ class Base:
                 if self.estop[2] == "IN":
                     if self.gpio.gpio_function(int(self.estop[1])) != "IN":
                         self.gpio.setup(int(self.estop[1]), self.gpio.IN)
+                    self.hal.newpin(self.estop[0], hal.HAL_BIT, hal.HAL_IN)
                 if self.estop[2] == "OUT":
                     if self.gpio.gpio_function(int(self.estop[1])) != "OUT":
                         self.gpio.setup(int(self.estop[1]), self.gpio.OUT)
-                self.hal.newpin(self.estop[0], hal.HAL_BIT, hal.HAL_IN)
+                    self.hal.newpin(self.estop[0], hal.HAL_BIT, hal.HAL_OUT)
             self.hal.ready()
 
     def loop(self):
         if self.hal and self.father.coordinates != "" and self.father.machine.machine_path != "":
             if self.estop:
-                estop_status = self.gpio.input(int(self.estop[1]))
-                self.hal[self.estop[0] + "a"] = estop_status
+                if self.hal[self.estop[0]]:
+                    estop_status = self.gpio.input(int(self.estop[1]))
+                    self.hal[self.estop[0]] = estop_status
         time.sleep(0.01)
 
